import React, { useState } from 'react';
import { Outlet, useLocation, useNavigate } from 'react-router-dom';
import { Header } from './Header';
import { Footer } from './Footer';
import { motion, AnimatePresence } from 'framer-motion';
import { useChatStore } from '../store/chat';
import { socket } from '../lib/socket';

export const Layout: React.FC = () => {
  const location = useLocation();
  const navigate = useNavigate();
  const isChat = location.pathname === '/chat';
  const isGroupChat = location.pathname === '/group-chat';
  const { isConnected } = useChatStore();
  const [isConfirmingExit, setIsConfirmingExit] = useState(false);
  
  // Handle browser back button and swipe gesture
  React.useEffect(() => {
    const handlePopState = (event: PopStateEvent) => {
      if (isChat && isConnected) {
        // Prevent default navigation
        event.preventDefault();
        window.history.pushState(null, '', '/chat');
        setIsConfirmingExit(true);
      }
    };

    // Push initial state to enable back handling
    if (isChat) {
      window.history.pushState(null, '', '/chat');
    }

    window.addEventListener('popstate', handlePopState);
    return () => window.removeEventListener('popstate', handlePopState);
  }, [isChat, isConnected]);

  // Lock body scroll when confirmation dialog is open
  React.useEffect(() => {
    if (isConfirmingExit) {
      document.body.style.overflow = 'hidden';
    } else {
      document.body.style.overflow = 'unset';
    }
    return () => {
      document.body.style.overflow = 'unset';
    };
  }, [isConfirmingExit]);

  const handleConfirmExit = () => {
    socket.emit('end_chat');
    setIsConfirmingExit(false);
    navigate('/');
  };

  return (
    <div className="flex flex-col min-h-screen bg-gray-50 dark:bg-gray-900 transition-colors duration-300">
      {isChat ? (
        <>
          <Header className="hidden md:block absolute top-0 left-0 right-0 z-10" />
          <main className="flex-1 relative">
            <Outlet />
          </main>

          <AnimatePresence>
            {isConfirmingExit && (
              <>
                <motion.div
                  initial={{ opacity: 0 }}
                  animate={{ opacity: 1 }}
                  exit={{ opacity: 0 }}
                  className="fixed inset-0 bg-black/50 backdrop-blur-sm z-50"
                  onClick={() => setIsConfirmingExit(false)}
                />
                <div className="fixed inset-0 flex items-end sm:items-center justify-center z-50 px-4 pb-4 sm:p-4">
                  <motion.div
                    initial={{ opacity: 0, y: 20 }}
                    animate={{ opacity: 1, y: 0 }}
                    exit={{ opacity: 0, y: 20 }}
                    className="w-full max-w-md bg-gray-900/95 backdrop-blur-xl rounded-t-2xl sm:rounded-2xl shadow-xl border border-gray-700/50"
                  >
                    <div className="p-6 space-y-4">
                      {/* Visual indicator for mobile swipe */}
                      <div className="sm:hidden w-12 h-1 bg-gray-700 rounded-full mx-auto mb-4" />
                      
                      <h3 className="text-xl font-semibold text-white">
                        Leave Chat?
                      </h3>
                      <p className="text-gray-300">
                        You are currently connected with a partner. Are you sure you want to leave? This will end your chat session.
                      </p>
                      <div className="flex flex-col sm:flex-row-reverse gap-2 sm:gap-3 pt-2">
                        <button
                          onClick={handleConfirmExit}
                          className="w-full sm:w-auto px-4 py-3 sm:py-2 text-sm font-medium text-white bg-gradient-to-r from-red-500 to-pink-500 hover:from-red-600 hover:to-pink-600 rounded-xl sm:rounded-lg transition-all duration-200 shadow-lg hover:shadow-xl"
                        >
                          Leave Chat
                        </button>
                        <button
                          onClick={() => setIsConfirmingExit(false)}
                          className="w-full sm:w-auto px-4 py-3 sm:py-2 text-sm font-medium text-gray-300 bg-gray-800 hover:bg-gray-700 rounded-xl sm:rounded-lg transition-colors border border-gray-700 hover:border-gray-600"
                        >
                          Cancel
                        </button>
                      </div>
                    </div>
                  </motion.div>
                </div>
              </>
            )}
          </AnimatePresence>
        </>
      ) : isGroupChat ? (
        <main className="flex-1 relative">
          <Outlet />
        </main>
      ) : (
        <>
          <Header className="sticky top-0 z-50" />
          <main className="flex-1 relative">
            <div className="absolute inset-0 bg-gradient-to-b from-blue-50/30 to-purple-50/30 dark:from-blue-900/20 dark:to-purple-900/20 transition-colors duration-300" />
            <div className="relative z-10">
              <Outlet />
            </div>
          </main>
          <Footer />
        </>
      )}
    </div>
  );
};